<?php declare (strict_types = 1);

namespace USKit\Base\Parts;

use Infomaker\Everyware\Base\Models\Post;
use Infomaker\Everyware\Support\GenericPropertyObject;
use Infomaker\Everyware\NewsML\NewsMLTransformerManager;
use Infomaker\Everyware\NewsML\Item;
use Infomaker\Everyware\Support\Interfaces\PropertyObject;
use Infomaker\Everyware\Base\OpenContent\OpenContentProvider;

class Concept extends GenericPropertyObject
{
    public function __construct(PropertyObject $object)
    {
        $this->fill($object->getProperties());
        $this->fill([
            'meta_data_array' => $this->getMetadata(),
        ]);
    }

    public function getMetadata(): array
    {
        $newsml = $this->getSingleValue('meta_data');

        if (empty($newsml)) {
            return [];
        }

        $transformer = NewsMLTransformerManager::createMetaDataTransformer();

        $result = $transformer->transform($newsml);

        if (empty($result)) {
            return [];
        }

        $data = array_shift($result);

        if ($data instanceof Item) {
            return $data->getProperties();
        }
    }

    public static function createFromPost(Post $post, $propertyMap = 'Concept')
    {
        $uuid = $post->getMeta('oc_uuid');

        $provider = OpenContentProvider::setup();
        $provider->setPropertyMap($propertyMap);
        $article = $provider->getObject($uuid);

        return new static($article);
    }
}
